@@ -13,7 +13,7 @@ import tijmp.ui.Translator;
 public class FilterOutClass extends FilterAction {
     private Class<?> clz;
     public FilterOutClass (FilterConfig fc, Class<?> clz) {
-	super ("Filter out " + Translator.translate (clz), fc);
+	super ("Filter out " + Translator.translate (clz, null), fc);
 	this.clz = clz;
     }
     
