@@ -12,13 +12,13 @@ public class InspectClass extends AbstractAction {
     private Class<?> clz;
 
     public InspectClass (Class<?> clz) {
-	super ("Inspect class " + Translator.translate (clz));
+	super ("Inspect class " + Translator.translate (clz, null));
 	this.clz = clz;
     }
 
     public void actionPerformed (ActionEvent e) {
 	ClassInspector ci = new ClassInspector (clz);
-	String cn = Translator.translate (clz);
+	String cn = Translator.translate (clz, null);
 	new ShowSimpleFrame ().showFrame (cn + " info", ci);
     }    
 }
