@@ -12,7 +12,7 @@ public class ShowAllInstances extends AbstractAction {
     private Class<?> clz;
     
     public ShowAllInstances (ProfilerHandler ph, Class<?> clz) {
-	super ("Show all instances of " + Translator.translate (clz));
+	super ("Show all instances of " + Translator.translate (clz, null));
 	this.ph = ph;
 	this.clz = clz;
     }
