@@ -12,7 +12,7 @@ public class ShowOwners extends AbstractAction {
     private Class<?> clz;
 
     public ShowOwners (ProfilerHandler ph, Class<?> clz) {
-	super ("Show owners for all " + Translator.translate (clz));
+	super ("Show owners for all " + Translator.translate (clz, null));
 	this.ph = ph;
 	this.clz = clz;
     }
