@@ -19,6 +19,8 @@ public class ThreadInfo extends AbstractAction {
 
     public void actionPerformed (ActionEvent e) {
 	ThreadInfoPanel tif = new ThreadInfoPanel (ph);
-	new ShowSimpleFrame ().showFrame ("Thread info " + + windowId++, tif);
+	ThreadDumper td = new ThreadDumper (tif);
+	new ShowSimpleFrame ().showFrame ("Thread info " + + windowId++, 
+					  tif, td);
     }    
 }
