@@ -4,6 +4,7 @@ import java.awt.BorderLayout;
 import java.awt.FlowLayout;
 import java.awt.event.ActionEvent;
 import java.awt.event.KeyEvent;
+import javax.swing.Action;
 import javax.swing.AbstractAction;
 import javax.swing.JButton;
 import javax.swing.JComponent;
@@ -15,12 +16,14 @@ import tijmp.actions.FrameCloser;
 /** A class that can show a simple window with a single component in it.
  */
 public class ShowSimpleFrame {
-    public void showFrame (String title, JComponent p) {
+    public void showFrame (String title, JComponent p, Action ... actions) {
 	JFrame f = new JFrame (title);
 	f.add (p, BorderLayout.CENTER);
 	f.setDefaultCloseOperation (JFrame.DISPOSE_ON_CLOSE);
 	JPanel buttons = new JPanel ();
 	buttons.setLayout (new FlowLayout (FlowLayout.RIGHT));
+	for (Action a : actions)
+	    buttons.add (new JButton (a));
 	final JButton close = new JButton (new FrameCloser (f));
 	buttons.add (close);
 	f.getRootPane ().setDefaultButton (close);
